@@ -453,6 +453,18 @@ def test_index_from_lattice_index():
         assert latt.index_from_lattice_index(ind) == i
 
 
+def test_get_base_atom_dict():
+    latt = Lattice(np.eye(2))
+    ata = latt.add_atom([0, 0], atom="A")
+    atb = latt.add_atom([0.5, 0], atom="B")
+    latt.add_atom([0.5, 0.5], atom="B")
+    result = latt.get_base_atom_dict()
+
+    assert len(result) == 2
+    assert_array_equal(result[ata], [[0, 0]])
+    assert_array_equal(result[atb], [[0.5, 0.], [0.5, 0.5]])
+
+
 def test_build():
     pass
 
@@ -505,6 +517,19 @@ def test_iter_neighbors(latt):
             assert_equal_elements(actual, expected)
 
 
+@given(structures())
+def test_check_neighbors(latt):
+    for i in range(latt.num_sites):
+        for distidx, neighbors in latt.iter_neighbors(i):
+            # Check neighbors
+            for j in neighbors:
+                assert latt.check_neighbors(i, j) == distidx
+            # Check not neighbors
+            for j in np.random.uniform(0, latt.num_sites, size=20):
+                if j not in list(neighbors):
+                    assert latt.check_neighbors(i, j) is None
+
+
 def test_compute_connections():
     latt = Lattice(np.eye(2))
     latt.add_atom()
@@ -559,6 +584,23 @@ def test_periodic_nearest():
     assert_elements_equal1d(latt.nearest_neighbors(20), [0, 15, 21, 24])
     assert_elements_equal1d(latt.nearest_neighbors(24), [4, 19, 20, 23])
 
+    # graphene lattice
+    latt = lp.graphene()
+    latt.build((5.5, 4.5))
+
+    latt.set_periodic(0)
+    assert_elements_equal1d(latt.nearest_neighbors(0), [1, 15])
+    assert_elements_equal1d(latt.nearest_neighbors(2), [3, 15, 21])
+    assert_elements_equal1d(latt.nearest_neighbors(8), [9, 21, 23])
+    latt.set_periodic(1)
+    assert_elements_equal1d(latt.nearest_neighbors(1), [0, 4, 16])
+    assert_elements_equal1d(latt.nearest_neighbors(6), [5, 7, 17])
+    assert_elements_equal1d(latt.nearest_neighbors(7), [6, 14, 22])
+    # Only check corners for both axis periodic
+    latt.set_periodic([0, 1])
+    assert_elements_equal1d(latt.nearest_neighbors(0), [1, 15, 23])
+    assert_elements_equal1d(latt.nearest_neighbors(8), [9, 21, 23])
+
 
 def test_periodic_next_nearest():
     # Lattice chain
@@ -669,6 +711,17 @@ def test_to_dict():
     assert_array_equal(d["shape"], expected)
 
 
+@given(structures())
+def test_fromdict(latt):
+    d = latt.todict()
+    latt2 = Lattice.fromdict(d)
+
+    assert_array_equal(latt.vectors, latt2.vectors)
+    assert_array_equal(latt.atom_positions, latt2.atom_positions)
+    assert_array_equal(latt._connections, latt2._connections)
+    assert_array_equal(latt.num_neighbors, latt2.num_neighbors)
+
+
 def test_hash():
     latt = Lattice(np.eye(2))
     latt.add_atom(atom=atom)
